@@ -8,20 +8,16 @@ from .base import DiscriminabilityTest
 
 class DiscrimTwoSample(DiscriminabilityTest):
     r"""
-    2 Sample Discriminability test statistic and p-value.
-
+    A class that compares the discriminability of two datasets.
     Two sample test measures whether the discriminability is different for
     one dataset compared to another. More details can be described in `[1]`_.
 
     Let :math:`\hat D_{x_1}` denote the sample discriminability of one approach,
     and :math:`\hat D_{x_2}` denote the sample discriminability of another approach.
     Then,
-
     .. math::
-
         H_0: D_{x_1} &= D_{x_2} \\
         H_A: D_{x_1} &> D_{x_2}
-
     Alternatively, tests can be done for :math:`D_{x_1} < D_{x_2}` and
     :math:`D_{x_1} \neq D_{x_2}`.
 
@@ -30,7 +26,7 @@ class DiscrimTwoSample(DiscriminabilityTest):
     Parameters
     ----------
     is_dist : bool, default: False
-        Whether inputs are distance matrices or not.
+        Whether `x1` and `x2` are distance matrices or not.
     remove_isolates : bool, default: True
         Whether to remove the measurements with a single instance or not.
     """
@@ -46,12 +42,12 @@ class DiscrimTwoSample(DiscriminabilityTest):
 
         Parameters
         ----------
-        x,y : ndarray
-            Input data matrices. ``x`` and ``y`` must have the same number of
-            samples. That is, the shapes must be ``(n, p)`` and ``(n, q)`` where
+        x, y : ndarray
+            Input data matrices. `x` and `y` must have the same number of
+            samples. That is, the shapes must be `(n, p)` and `(n, q)` where
             `n` is the number of samples and `p` and `q` are the number of
-            dimensions. Alternatively, ``x`` and ``y`` can be distance matrices,
-            where the shapes must both be ``(n, n)``.
+            dimensions. Alternatively, `x` and `y` can be distance matrices,
+            where the shapes must both be `(n, n)`.
 
         Returns
         -------
@@ -62,34 +58,34 @@ class DiscrimTwoSample(DiscriminabilityTest):
 
         return stat
 
-    def test(self, x1, x2, y, reps=1000, alt="neq", workers=1):
+    def test(self, x1, x2, y, reps=1000, alt="neq", workers=-1):
         r"""
         Calculates the test statistic and p-value for a two sample test for
         discriminability.
 
         Parameters
         ----------
-        x1,x2 : ndarray
-            Input data matrices. ``x1`` and ``x2`` must have the same number of
-            samples. That is, the shapes must be ``(n, p)`` and ``(n, q)`` where
+        x1, x2 : ndarray
+            Input data matrices. `x1` and `x2` must have the same number of
+            samples. That is, the shapes must be `(n, p)` and `(n, q)` where
             `n` is the number of samples and `p` and `q` are the number of
-            dimensions. Alternatively, ``x1`` and ``x2`` can be distance matrices,
-            where the shapes must both be ``(n, n)``, and ``is_dist`` must set
+            dimensions. Alternatively, `x1` and `x2` can be distance matrices,
+            where the shapes must both be `(n, n)`, and ``is_dist`` must set
             to ``True`` in this case.
         y : ndarray
             A vector containing the sample ids for our `n` samples. Should be matched
             to the inputs such that ``y[i]`` is the corresponding label for
             ``x_1[i, :]`` and ``x_2[i, :]``.
-        reps : int, default: 1000
+        reps : int, optional (default: 1000)
             The number of replications used to estimate the null distribution
             when using the permutation test used to calculate the p-value.
-        alt : {"neq", "greater", "less"}, default: "neq"
+        alt : {"greater", "less", "neq"} (default: "neq")
             The alternative hypothesis for the test. Can test that first dataset is
-            more discriminable (``alt="greater"``), less discriminable (``alt="less"``)
-            or unequal discriminability (``alt="neq"``).
-        workers : int, default: 1
+            more discriminable (alt = "greater"), less discriminable (alt = "less")
+            or unequal discriminability (alt = "neq").
+        workers : int, optional (default: -1)
             The number of cores to parallelize the p-value computation over.
-            Supply ``-1`` to use all cores available to the Process.
+            Supply -1 to use all cores available to the Process.
 
         Returns
         -------
@@ -107,7 +103,8 @@ class DiscrimTwoSample(DiscriminabilityTest):
         >>> x1 = np.ones((100,2), dtype=float)
         >>> x2 = np.concatenate([np.zeros((50, 2)), np.ones((50, 2))], axis=0)
         >>> y = np.concatenate([np.zeros(50), np.ones(50)], axis=0)
-        >>> '%.1f, %.1f, %.2f' % DiscrimTwoSample().test(x1, x2, y) # doctest: +SKIP
+        >>> discrim1, discrim2, pvalue = DiscrimTwoSample().test(x1, x2, y)
+        >>> '%.1f, %.1f, %.2f' % (discrim1, discrim2, pvalue)
         '0.5, 1.0, 0.00'
         """
 
@@ -143,7 +140,6 @@ class DiscrimTwoSample(DiscriminabilityTest):
             msg = "You have not entered a valid alternative."
             raise ValueError(msg)
 
-        # check if discrim is correct
         if pvalue == 0:
             pvalue = 1 / reps
 
@@ -151,7 +147,7 @@ class DiscrimTwoSample(DiscriminabilityTest):
 
         return self.d1, self.d2, self.pvalue
 
-    def _get_convex_comb(self, x):
+    def _get_convex_comb(self, x):  # pragma: no cover
         """Get random convex combination of input x."""
         n, _ = x.shape
 
@@ -173,7 +169,7 @@ class DiscrimTwoSample(DiscriminabilityTest):
 
         Returns
         -------
-        perm_stat1,perm_stat2 : float
+        perm_stat1, perm_stat2 : float
             Test statistic for each value in the null distribution.
         """
         permx1 = self._get_convex_comb(self.x1)
@@ -186,7 +182,7 @@ class DiscrimTwoSample(DiscriminabilityTest):
 
 
 @jit(nopython=True, cache=True)
-def calculate_diff_null(null_dist, reps):
+def calculate_diff_null(null_dist, reps):  # pragma: no cover
     """
     Helper function to calculate the distribution of thedifference under
     null.
