@@ -1,8 +1,8 @@
 import numpy as np
 import pytest
-from numpy.testing import assert_approx_equal
+from numpy.testing import assert_almost_equal, assert_approx_equal
 
-from ...tools import linear, multimodal_independence, spiral
+from ...tools import linear, multimodal_independence, power, spiral
 from .. import MGC
 
 
@@ -14,7 +14,6 @@ class TestMGCStat(object):
         [
             (linear, 0.97, 1 / 1000),  # test linear simulation
             (spiral, 0.163, 1 / 1000),  # test spiral simulation
-            (multimodal_independence, -0.0094, 0.78),  # test independence simulation
         ],
     )
     def test_oned(self, sim, obs_stat, obs_pvalue):
@@ -49,3 +48,18 @@ class TestMGCStat(object):
         assert_approx_equal(stat1, obs_stat, significant=1)
         assert_approx_equal(stat2, obs_stat, significant=1)
         assert_approx_equal(pvalue, obs_pvalue, significant=1)
+
+
+class TestMGCTypeIError:
+    def test_oned(self):
+        np.random.seed(123456789)
+        est_power = power(
+            "MGC",
+            sim_type="indep",
+            sim="multimodal_independence",
+            n=50,
+            p=1,
+            alpha=0.05,
+        )
+
+        assert_almost_equal(est_power, 0.05, decimal=2)
